@@ -1,7 +1,7 @@
-from sqlspec.adapters.adbc.config import Adbc
+from sqlspec.adapters.adbc.config import AdbcConfig
 from sqlspec.adapters.adbc.driver import AdbcDriver
 
 __all__ = (
-    "Adbc",
+    "AdbcConfig",
     "AdbcDriver",
 )
