@@ -1,7 +1,7 @@
-from sqlspec.adapters.aiosqlite.config import Aiosqlite
+from sqlspec.adapters.aiosqlite.config import AiosqliteConfig
 from sqlspec.adapters.aiosqlite.driver import AiosqliteDriver
 
 __all__ = (
-    "Aiosqlite",
+    "AiosqliteConfig",
     "AiosqliteDriver",
 )
