@@ -16,8 +16,8 @@ if TYPE_CHECKING:
     from asyncmy.pool import Pool  # pyright: ignore[reportUnknownVariableType]
 
 __all__ = (
-    "Asyncmy",
-    "AsyncmyPool",
+    "AsyncmyConfig",
+    "AsyncmyPoolConfig",
 )
 
 
@@ -25,7 +25,7 @@ T = TypeVar("T")
 
 
 @dataclass
-class AsyncmyPool(GenericPoolConfig):
+class AsyncmyPoolConfig(GenericPoolConfig):
     """Configuration for Asyncmy's connection pool.
 
     This class provides configuration options for Asyncmy database connection pools.
@@ -104,19 +104,19 @@ class AsyncmyPool(GenericPoolConfig):
 
 
 @dataclass
-class Asyncmy(AsyncDatabaseConfig["Connection", "Pool", "AsyncmyDriver"]):
+class AsyncmyConfig(AsyncDatabaseConfig["Connection", "Pool", "AsyncmyDriver"]):
     """Asyncmy Configuration."""
 
     __is_async__ = True
     __supports_connection_pooling__ = True
 
-    pool_config: "Optional[AsyncmyPool]" = None
+    pool_config: "Optional[AsyncmyPoolConfig]" = None
     """Asyncmy Pool configuration"""
-    connection_type: "type[Connection]" = field(init=False, default_factory=lambda: Connection)  # pyright: ignore
+    connection_type: "type[Connection]" = field(hash=False, init=False, default_factory=lambda: Connection)  # pyright: ignore
     """Type of the connection object"""
-    driver_type: "type[AsyncmyDriver]" = field(init=False, default_factory=lambda: AsyncmyDriver)
+    driver_type: "type[AsyncmyDriver]" = field(hash=False, init=False, default_factory=lambda: AsyncmyDriver)
     """Type of the driver object"""
-    pool_instance: "Optional[Pool]" = None  # pyright: ignore[reportUnknownVariableType]
+    pool_instance: "Optional[Pool]" = field(hash=False, default=None)  # pyright: ignore[reportUnknownVariableType]
     """Instance of the pool"""
 
     @property
@@ -162,7 +162,7 @@ class Asyncmy(AsyncDatabaseConfig["Connection", "Pool", "AsyncmyDriver"]):
         raise ImproperConfigurationError(msg)
 
     async def create_connection(self) -> "Connection":  # pyright: ignore[reportUnknownParameterType]
-        """Create and return a new asyncmy connection.
+        """Create and return a new asyncmy connection from the pool.
 
         Returns:
             A Connection instance.
@@ -171,9 +171,8 @@ class Asyncmy(AsyncDatabaseConfig["Connection", "Pool", "AsyncmyDriver"]):
             ImproperConfigurationError: If the connection could not be created.
         """
         try:
-            import asyncmy  # pyright: ignore[reportMissingTypeStubs]
-
-            return await asyncmy.connect(**self.connection_config_dict)  # pyright: ignore
+            async with self.provide_connection() as conn:
+                return conn
         except Exception as e:
             msg = f"Could not configure the Asyncmy connection. Error: {e!s}"
             raise ImproperConfigurationError(msg) from e
