@@ -1,7 +1,7 @@
-from sqlspec.adapters.duckdb.config import DuckDB
+from sqlspec.adapters.duckdb.config import DuckDBConfig
 from sqlspec.adapters.duckdb.driver import DuckDBDriver
 
 __all__ = (
-    "DuckDB",
+    "DuckDBConfig",
     "DuckDBDriver",
 )
