@@ -1,7 +1,7 @@
-from sqlspec.adapters.sqlite.config import Sqlite
+from sqlspec.adapters.sqlite.config import SqliteConfig
 from sqlspec.adapters.sqlite.driver import SqliteDriver
 
 __all__ = (
-    "Sqlite",
+    "SqliteConfig",
     "SqliteDriver",
 )
