@@ -1,9 +1,8 @@
 """General utility functions."""
 
-from __future__ import annotations
-
 import re
 import unicodedata
+from typing import Optional
 
 __all__ = (
     "check_email",
@@ -19,7 +18,7 @@ def check_email(email: str) -> str:
     return email.lower()
 
 
-def slugify(value: str, allow_unicode: bool = False, separator: str | None = None) -> str:
+def slugify(value: str, allow_unicode: bool = False, separator: "Optional[str]" = None) -> str:
     """Slugify.
 
     Convert to ASCII if ``allow_unicode`` is ``False``. Convert spaces or repeated
